#
# spec file for package libyui-bindings
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#
# nodebuginfo


Name:           libyui-bindings
Version:        1.1.0
Release:        6.1
Summary:        Bindings for libyui
License:        LGPL-2.1 or LGPL-3.0
Group:          Development/Sources
Url:            https://github.com/libyui/libyui-bindings
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  cmake
BuildRequires:  gcc-c++
BuildRequires:  libyui-devel >= 2.21.5
BuildRequires:  perl
BuildRequires:  python-devel
BuildRequires:  ruby-devel
BuildRequires:  swig
Source:         %{name}-%{version}.tar.bz2
Prefix:         /usr

%description
This package provides Ruby language bindings to access functions of
libyui - An User Interface engine that provides the
abstraction from graphical user interfaces (Qt, Gtk) and text based
user interfaces (ncurses).

Authors:
---------
-    kkaempf@suse.de
-    dmacvicar@suse.de

%prep
%setup -q

%build
mkdir build
cd build
cmake -DYPREFIX=%{prefix} \
      -DCMAKE_INSTALL_PREFIX=%{prefix} \
      -DLIB=%{_lib} \
      -DPYTHON_SITEDIR=%{py_sitedir} \
      -DCMAKE_VERBOSE_MAKEFILE=TRUE \
      -DCMAKE_C_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_CXX_FLAGS_RELEASE:STRING="%{optflags}" \
      -DCMAKE_BUILD_TYPE=Release \
      -DCMAKE_SKIP_RPATH=1 \
      -DBUILD_RUBY_GEM=no \
      ..
make %{?jobs:-j %jobs}

%install
cd build
make install DESTDIR=$RPM_BUILD_ROOT

%clean
%{__rm} -rf %{buildroot}

%package -n ruby-yui
Summary:        Ruby bindings for libyui
Group:          Development/Languages/Ruby

%description -n ruby-yui
This package provides Ruby language bindings to access functions of
libyui - An User Interface engine that provides the
abstraction from graphical user interfaces (Qt, Gtk) and text based
user interfaces (ncurses).

Authors:
---------
-    kkaempf@suse.de
-    dmacvicar@suse.de

%package -n python-yui
%py_requires
Summary:        Python bindings for libyui
Group:          Development/Languages/Python

%description -n python-yui
This package provides Python language bindings to access functions of
yast2-libyui - An User Interface engine that provides the
abstraction from graphical user interfaces (Qt, Gtk) and text based
user interfaces (ncurses).

Authors:
---------
-    kkaempf@suse.de
-    dmacvicar@suse.de


%package -n perl-yui
%{perl_requires}
Summary:        Perl bindings for libyui
Group:          Development/Languages/Perl

%description -n perl-yui
This package provides Perl language bindings to access functions of
yast2-libyui - An User Interface engine that provides the
abstraction from graphical user interfaces (Qt, Gtk) and text based
user interfaces (ncurses).

Authors:
---------
-    kkaempf@suse.de
-    dmacvicar@suse.de


%files -n ruby-yui
%defattr(-,root,root,-)
%doc swig/ruby/examples/*.rb
%{_libdir}/ruby/vendor_ruby/%{rb_ver}/%{rb_arch}/_yui.so

%files -n python-yui
%defattr(-,root,root,-)
%doc swig/python/examples/*.py
%{py_sitedir}/_yui.so
%{py_sitedir}/yui.py

%files -n perl-yui
%defattr(-,root,root,-)
%doc swig/perl/examples/*.pl
%{perl_vendorarch}/yui.so
%{perl_vendorlib}/yui.pm

%changelog
* Sun Jan 18 2015 besser82@fedoraproject.org
- Replace deprecated Config: with RbConfig: for Ruby 2.2
- Add bindings for Mono / CSharp thanks to Matteo Pasotti
  <matteo@mageia.org>
- Add CMake-switches to enable / disable languages thanks to
  Matteo Pasotti <matteo@mageia.org>
- Shapen-up Mono-bindings to work as expected
- 1.1.0
* Thu Jan 15 2015 mvidner@suse.com
- Fixed building with cmake 3.1 (-fPIC, PREFIX, boo#911875).
- 1.0.6
* Wed Sep 10 2014 mvidner@suse.com
- Enabled building (but not running) from a non /usr prefix,
  for ci.opensuse.org.
- 1.0.5
* Fri Jan 24 2014 anaselli@linux.it
- Added convertors and incrementers needed at least for Perl
  and python:
  YEvent: toYWidgetEvent toYKeyEvent toYMenuEvent toYCancelEvent
    toYDebugEvent toYTimeoutEvent
  YItem: toYTreeItem toYTableItem
  YItemIterator: toYItem incrYItemIterator
  YTableCellIterator: toYTableCell incrYTableCellIterator
- new Version 1.0.4
* Mon Dec  2 2013 anaselli@linux.it
- added new file checking for YExternalWidgets plugin management
- new Version 1.0.3
* Fri May 31 2013 bjoern.esser@gmail.com
- license update: LGPL-2.1 or LGPL-3
- get rid of `/usr/bin/env` in hashbang of examples
- new Version 1.0.2
* Mon Aug 13 2012 cfarrell@suse.com
- license update: GPL-2.0
  SPDX format (http://www.spdx.org/licenses) should be used for spec file
  license field
* Fri Aug 10 2012 kkaempf@suse.com
- Update to 1.0.0 for stand-alone libyui
* Tue Jun 12 2012 kkaempf@suse.com
- Build stand-alone (without YaST)
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Thu Aug  7 2008 kkaempf@suse.de
- use rpm macros for Perl and Python directories. Fixes building
  against Python 2.6.
* Fri May 23 2008 kkaempf@suse.de
- fix widget (pointer) comparison for Perl and Python.
* Tue May 20 2008 kkaempf@suse.de
- Fix requires for perl-yui (bnc#392558)
* Tue May 20 2008 kkaempf@suse.de
- follow naming conventions (bnc#392524). Its now ruby-yui,
  python-yui and perl-yui.
* Mon May 19 2008 kkaempf@suse.de
- Add examples for Perl and Python
* Fri May 16 2008 kkaempf@suse.de
- Also generate Python (libyui-python) and Perl (perl-libyui)
  bindings.
* Tue May 13 2008 kkaempf@suse.de
- Add copyright (gpl 2.0) (bnc#379919)
- Add Ruby examples.
* Mon Apr 14 2008 kkaempf@suse.de
- Extended, now sufficient for selection_box1.
* Fri Apr 11 2008 kkaempf@suse.de
- Initial version, just enough for 'Hello, world!'
